==> mongodb-7.0.18.gh.tar.gz: mongo-r7.0.18/src/mongo/db/query/ce/heuristic_estimator.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/query/optimizer/cascades/interfaces.h"

namespace mongo::optimizer::ce {

/**
 * Default cardinality estimation in the absence of statistics.
 * Relies purely on heuristics.
 * We currently do not use logical properties for heuristic ce.
 */
class HeuristicEstimator : public cascades::CardinalityEstimator {
public:
    CEType deriveCE(const Metadata& metadata,
                    const cascades::Memo& memo,
                    const properties::LogicalProps& /*logicalProps*/,
                    ABT::reference_type logicalNodeRef) const override final;
};

}  // namespace mongo::optimizer::ce

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/db/query/ce/heuristic_estimator.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/query/optimizer/cascades/interfaces.h"
#include "mongo/db/query/optimizer/defs.h"
#include "mongo/db/query/optimizer/metadata.h"
#include "mongo/db/query/optimizer/props.h"
#include "mongo/db/query/optimizer/syntax/syntax.h"

namespace mongo::optimizer::ce {

/**
 * Default cardinality estimation in the absence of statistics.
 * Relies purely on heuristics.
 * We currently do not use logical properties for heuristic ce.
 */
class HeuristicEstimator : public cascades::CardinalityEstimator {
public:
    CERecord deriveCE(const Metadata& metadata,
                      const cascades::Memo& memo,
                      const properties::LogicalProps& /*logicalProps*/,
                      const QueryParameterMap& queryParameters,
                      ABT::reference_type logicalNodeRef) const final;
};

}  // namespace mongo::optimizer::ce
